<template>
  <div :class="className" :style="{height:height,width:width}" />
</template>

<script>
import * as echarts from 'echarts'
require('echarts/theme/macarons') // echarts theme
import resize from './mixins/resize'
import { getTopProcess } from "@/api/main/da/passingStationCollection/passingStationCollection";

export default {
  mixins: [resize],
  props: {
    className: {
      type: String,
      default: 'chart'
    },
    width: {
      type: String,
      default: '100%'
    },
    height: {
      type: String,
      default: '350px'
    }
  },
  data() {
    return {
      chart: null,
      data: [],
      title:[],
    }
  },
  mounted() {
    this.getData()

  },
  beforeDestroy() {
    if (!this.chart) {
      return
    }
    this.chart.dispose()
    this.chart = null
  },
  methods: {
    getData(){
      getTopProcess().then(res => {
        if (res.code === 200){
          this.data = res.rows
          this.data.forEach(x => {
            this.title.push(x.name)
          })
          this.$nextTick(() => {
            this.initChart()
          })
        }
      })
    },
    initChart() {
      this.chart = echarts.init(this.$el, 'macarons')

      this.chart.setOption({
        title: {
          text: '工位堵塞Top5', // 标题文本
          left: 'center' // 标题位置
        },
        tooltip: {
          trigger: 'item',
          formatter: '{a} <br/>{b} : {c} ({d}%)'
        },
        // textStyle
        legend: {
          orient: 'vertical',

          left: 'left',
          // left: 'center',
          // bottom: '10',//左侧高度
          data: this.title
        },
        series: [
          {
            name: 'WEEKLY WRITE ARTICLES',
            type: 'pie',
            // roseType: 'radius',//更改样式
            radius: '50%',
            // labelLine: {
            //   length: 10 // 调整标签线的长度
            // },
            center: ['50%', '60%'],
            data: this.data,
            label: {
              formatter: '{b}: {c} ({d}%)'
            },
            animationEasing: 'cubicInOut',
            animationDuration: 2600
          }
        ]
      })
    }
  }
}
</script>
